#!/bin/bash

# This script is started by scanbuttond whenever a scanner button has been pressed.
# Scanbuttond passes the following parameters to us:
# $1 ... the button number
# $2 ... the scanner's SANE device name, which comes in handy if there are two or 
#        more scanners. In this case we can pass the device name to SANE programs 
#        like scanimage.

# Name of the scanner
SCANNER="Plustek OpticSlim 2400 flatbed scanner"
# You can also use $2 instead of the scanner name
#SCANNER=$2

SCAN2FILE="$HOME"/bin/scan2file/scan2file-v1.1.sh
DSTDIR="$HOME"/Desktop/Scans
LOCKFILE="/tmp/$USER.copy"
SND_PLAYER="ogg123"
SND_BUTTONPRESSED="/usr/share/sounds/KDE_Click_3.ogg"
SND_SCANNER_READY="/usr/share/sounds/KDE_Event_3.ogg"

set -e

trap "lockfile-remove $LOCKFILE && rm -f /tmp/Scan.pdf && $SND_PLAYER $SND_SCANNER_READY > /dev/null 2>&1 && echo \"'$SCANNER' is ready.\" && echo \"################################################################################\" && echo" EXIT

$SND_PLAYER $SND_BUTTONPRESSED > /dev/null 2>&1

if ! lockfile-create $LOCKFILE; then
  echo "Error: Scanning already in progress for '$SCANNER'."
  echo "       If you are sure that the scanner is not in use"
  echo "       please remove $LOCKFILE.lock."
  exit
fi

case $1 in
  1)
    echo "Botton 'Copy' pressed on '$SCANNER'."
    "$SCAN2FILE" -d "$SCANNER" -o print:
    ;;
  2)
    echo "Botton 'OCR' pressed on '$SCANNER'."
    [ ! -e "$DSTDIR" ] && mkdir -p "$DSTDIR"
    "$SCAN2FILE" -d "$SCANNER" -o "$DSTDIR" -f txt
    ;;
  3)
    echo "Botton 'E-Mail' pressed on '$SCANNER'."
    "$SCAN2FILE" -d "$SCANNER" -o /tmp/Scan.pdf
    echo "Waiting for Mail program to terminate..."
    kmail --subject Scan --attach /tmp/Scan.pdf
    # thunderbird -compose subject=Scan,attachment=file:///tmp/Scan.pdf
    # icedove -compose subject=Scan,attachment=file:///tmp/Scan.pdf
    # Wait for the mail client to load the attachment
    sleep 4
    echo
    echo "done."
    ;;
  4)
    echo "Botton 'Custom' pressed on '$SCANNER'."
    [ ! -e "$DSTDIR" ] && mkdir -p "$DSTDIR"
    "$SCAN2FILE" -d "$SCANNER" -o "$DSTDIR" -m color -f pnm
    ;;
  5)
    echo "Botton 'SCAN' pressed on '$SCANNER'."
    [ ! -e "$DSTDIR" ] && mkdir -p "$DSTDIR"
    "$SCAN2FILE" -d "$SCANNER" -o "$DSTDIR" -f pdf
    ;;
esac

